@@ -1,6 +1,7 @@
 """
 Main CLI entrypoint.
 """
+
 import sys
 
 
@@ -9,13 +10,13 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.Organizations 1.19.5\n"
-        "Version:         1.19.5\n"
-        "Builder version: 6.0.2\n"
-        "Docs:            https://pypi.org/project/mypy-boto3-organizations/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.19.5/reference/services/organizations.html#Organizations\n"
+        "Type annotations for boto3.Organizations 1.34.56\n"
+        "Version:         1.34.56\n"
+        "Builder version: 7.23.2\n"
+        "Docs:            https://youtype.github.io/boto3_stubs_docs/mypy_boto3_organizations//\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/organizations.html#Organizations\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
-        "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
+        "Changelog:       https://github.com/youtype/mypy_boto3_builder/releases"
     )
 
 
@@ -23,7 +24,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.19.5")
+    print("1.34.56")
 
 
 def main() -> None:
